@@ -87,7 +87,7 @@ class VersionAdmin(admin.ModelAdmin):
                         for field in inline_model._meta.fields:
                             if isinstance(field, (models.ForeignKey, models.OneToOneField)) and issubclass(self.model, field.rel.to):
                                 fk_name = field.name
-                    self._autoregister(inline_model, follow=(fk_name,))
+                    self._autoregister(inline_model, follow=[fk_name])
                     if not inline_model._meta.get_field(fk_name).rel.is_hidden():
                         accessor = inline_model._meta.get_field(fk_name).related.get_accessor_name()
                         inline_fields.append(accessor)
@@ -383,8 +383,8 @@ class VersionAdmin(admin.ModelAdmin):
     def revision_view(self, request, object_id, version_id, extra_context=None):
         """Displays the contents of the given revision."""
         object_id = unquote(object_id) # Underscores in primary key get quoted to "_5F"
-        obj = get_object_or_404(self.model, pk=object_id)
-        version = get_object_or_404(Version, pk=version_id, object_id=unicode(obj.pk))
+        version = get_object_or_404(Version, pk=version_id, object_id=unicode(object_id))
+        obj = version.object_version.object
         # Generate the context.
         context = {"title": _("Revert %(name)s") % {"name": force_unicode(self.model._meta.verbose_name)},}
         context.update(extra_context or {})
@@ -455,4 +455,4 @@ class VersionMetaAdmin(VersionAdmin):
     def get_date_modified(self, obj):
         """Displays the last modified date of the given object, typically for use in a change list."""
         return localize(obj.date_modified)
-    get_date_modified.short_description = "date modified"
\ No newline at end of file
+    get_date_modified.short_description = "date modified"
